@@ -7,7 +7,7 @@ require "minitest/parallel"
 # :include: README.txt
 
 module Minitest
-  VERSION = "5.4.0" # :nodoc:
+  VERSION = "5.4.2" # :nodoc:
 
   @@installed_at_exit ||= false
   @@after_run = []
@@ -306,8 +306,10 @@ module Minitest
       on_signal "INFO", handler, &block
     end
 
+    SIGNALS = Signal.list
+
     def self.on_signal name, action # :nodoc:
-      supported = Signal.list[name]
+      supported = SIGNALS[name]
 
       old_trap = trap name do
         old_trap.call if old_trap.respond_to? :call
